from setuptools import setup
 
setup(
     name='with-aws-mfa',    # This is the name of your PyPI-package.
     version='0.3',                          # Update the version number for new releases
     scripts=['with-aws-mfa'],                  # The name of your scipt, and also the command you'll be using for calling it
     author='Dan Aronson',
     author_email='dan.aronson@gmail.com',
     url='https://github.com/danaronson/with_aws_mfa',
     install_requires=[
       'enum34;python_version<"3.4"',
       'boto3'
       ]
 )
